@@ -2,6 +2,7 @@
 #  pylint: disable=no-self-use
 from collections import defaultdict
 
+from PIL import Image
 from rest_framework import serializers
 
 from network.base.db_api import DBConnectionError, get_tle_sets_by_norad_id_set, \
@@ -15,6 +16,34 @@ from network.base.validators import ObservationOverlapError, OutOfRangeError, ch
     check_transmitter_station_pairs
 
 
+class CreateDemodDataSerializer(serializers.ModelSerializer):
+    """SatNOGS Network DemodData API Serializer for creating demoddata."""
+    class Meta:
+        model = DemodData
+        fields = (
+            'observation',
+            'demodulated_data',
+        )
+
+    def create(self, validated_data):
+        """Creates demoddata from a list of validated data after checking if demodulated_data is an
+        image and add the result in is_image field
+        """
+        try:
+            image = Image.open(validated_data['demodulated_data'])
+            image.verify()
+            validated_data['is_image'] = True
+        except Exception:  # pylint: disable=W0703
+            validated_data['is_image'] = False
+        return DemodData.objects.create(**validated_data)
+
+    def update(self, instance, validated_data):
+        """Updates demoddata from a list of validated data
+        currently disabled and returns None
+        """
+        return None
+
+
 class DemodDataSerializer(serializers.ModelSerializer):
     """SatNOGS Network DemodData API Serializer"""
     payload_demod = serializers.SerializerMethodField()
