@@ -18,7 +18,8 @@ from internetarchive import upload
 from internetarchive.exceptions import AuthenticationError
 from tinytag import TinyTag, TinyTagException
 
-from network.base.db_api import DBConnectionError, get_tle_sets_by_norad_id_set
+from network.base.db_api import DBConnectionError, get_tle_sets_by_norad_id_set, \
+    get_transmitters_by_uuid_set
 from network.base.models import DemodData, Observation, Satellite, Station
 from network.base.rating_tasks import rate_observation
 from network.base.utils import sync_demoddata_to_db
@@ -107,7 +108,7 @@ def process_audio(observation_id, force_zip=False):
             if audio_metadata.duration is None or audio_metadata.duration < 1:
                 observation.payload.delete()
                 return
-            rate_observation.delay(observation_id, 'audio_upload', audio_metadata.duration)
+            rate_observation(observation_id, 'audio_upload', audio_metadata.duration)
             if (settings.ZIP_AUDIO_FILES or force_zip) and not settings.USE_S3_STORAGE_FOR_AUDIO:
                 zip_audio(observation_id, observation.payload.path)
         except TinyTagException:
@@ -289,6 +290,43 @@ def update_future_observations_with_new_tle_sets():
         )
 
 
+@shared_task
+def update_future_observations_with_new_transmitter_details():
+    """ Update future observations with latest Transmitter details"""
+    start = now() + timedelta(minutes=10)
+    future_observations = Observation.objects.filter(start__gt=start)
+    uuid_set = set(future_observations.values_list('transmitter_uuid', flat=True))
+
+    try:
+        if uuid_set:
+            transmitters_set = get_transmitters_by_uuid_set(uuid_set)
+        else:
+            return
+    except DBConnectionError:
+        return
+
+    for uuid in transmitters_set.keys():
+        transmitter = transmitters_set[uuid]
+        transmitter_updated = datetime.strptime(transmitter['updated'], "%Y-%m-%dT%H:%M:%S.%f%z")
+
+        future_observations.filter(
+            transmitter_uuid=uuid, transmitter_created__lt=transmitter_updated
+        ).update(
+            transmitter_description=transmitter['description'],
+            transmitter_type=transmitter['type'],
+            transmitter_uplink_low=transmitter['uplink_low'],
+            transmitter_uplink_high=transmitter['uplink_high'],
+            transmitter_uplink_drift=transmitter['uplink_drift'],
+            transmitter_downlink_low=transmitter['downlink_low'],
+            transmitter_downlink_high=transmitter['downlink_high'],
+            transmitter_downlink_drift=transmitter['downlink_drift'],
+            transmitter_mode=transmitter['mode'],
+            transmitter_invert=transmitter['invert'],
+            transmitter_baud=transmitter['baud'],
+            transmitter_created=transmitter['updated'],
+        )
+
+
 @shared_task
 def fetch_data():
     """Fetch all satellites and transmitters from SatNOGS DB
